@@ -38,7 +38,7 @@
 #' links_secuTrial(sT_export, forms = "^ctu05")
 #' }
 links_secuTrial <- function(object, forms = NULL, formcol = "#d8b365", varcol = "#e5f5f9", plot = TRUE) {
-  if (!class(object) == "secuTrialdata") stop("object of class secuTrialdata expected")
+  if (!inherits(object, "secuTrialdata")) stop("object of class secuTrialdata expected")
   obj <- object[2:length(object)]
 
 
